﻿// dllmain.cpp : DLL アプリケーションのエントリ ポイントを定義します。
#include "pch.h"
#include "atlstr.h"

typedef struct Mesh {
	int vertexCount;        // Number of vertices stored in arrays
	int triangleCount;      // Number of triangles stored (indexed or not)

	// Default vertex data
	float *vertices;        // Vertex position (XYZ - 3 components per vertex) (shader-location = 0)
	float *texcoords;       // Vertex texture coordinates (UV - 2 components per vertex) (shader-location = 1)
	float *texcoords2;      // Vertex second texture coordinates (useful for lightmaps) (shader-location = 5)
	float *normals;         // Vertex normals (XYZ - 3 components per vertex) (shader-location = 2)
	float *tangents;        // Vertex tangents (XYZW - 4 components per vertex) (shader-location = 4)
	unsigned char *colors;  // Vertex colors (RGBA - 4 components per vertex) (shader-location = 3)
	unsigned short *indices;// Vertex indices (in case vertex data comes indexed)

	// Animation vertex data
	float *animVertices;    // Animated vertex positions (after bones transformations)
	float *animNormals;     // Animated normals (after bones transformations)
	int *boneIds;           // Vertex bone ids, up to 4 bones influence by vertex (skinning)
	float *boneWeights;     // Vertex bone weight, up to 4 bones influence by vertex (skinning)

	// OpenGL identifiers
	unsigned int vaoId;     // OpenGL Vertex Array Object id
	unsigned int *vboId;    // OpenGL Vertex Buffer Objects id (default vertex data)
} Mesh;

#define RLAPI extern "C" __declspec(dllexport) 

RLAPI void UnloadMesh(Mesh mesh)
{
	CString strMsg;

	if ( mesh.vertexCount != 1)
	{
		strMsg.Append(L"mesh.vertexCount\r\n");
	}

	if (mesh.triangleCount != 2)
	{
		strMsg.Append(L"mesh.triangleCount\r\n");
	}

	if (mesh.vertices != (float*)3)
	{
		strMsg.Append(L"mesh.vertices\r\n");
	}

	if (mesh.texcoords != (float*)4)
	{
		strMsg.Append(L"mesh.texcoords\r\n");
	}

	if (mesh.texcoords2 != (float*)5)
	{
		strMsg.Append(L"mesh.texcoords2\r\n");
	}

	if (mesh.normals != (float*)6)
	{
		strMsg.Append(L"mesh.normals\r\n");
	}

	if (mesh.tangents != (float*)7)
	{
		strMsg.Append(L"mesh.tangents\r\n");
	}

	if (mesh.colors != (unsigned char*)8)
	{
		strMsg.Append(L"mesh.colors\r\n");
	}

	if (mesh.indices != (unsigned short*)9)
	{
		strMsg.Append(L"mesh.indices\r\n");
	}

	if (mesh.animVertices != (float*)10)
	{
		strMsg.Append(L"mesh.animVertices\r\n");
	}

	if (mesh.animNormals != (float*)11)
	{
		strMsg.Append(L"mesh.animNormals\r\n");
	}

	if (mesh.boneIds != (int*)12)
	{
		strMsg.Append(L"mesh.boneIds\r\n");
	}
	
	if (mesh.boneWeights != (float*)13)
	{
		strMsg.Append(L"mesh.boneWeights\r\n");
	}

	if (mesh.vaoId != 14)
	{
		strMsg.Append(L"mesh.vaoId\r\n");
	}

	if (mesh.vboId != (unsigned int*)15)
	{
		strMsg.Append(L"mesh.vboId\r\n");
	}

	if (!strMsg.IsEmpty())
	{
		::MessageBox(::GetActiveWindow(), strMsg, L"想定と違うパラメータがありました", MB_OK);
	}
}

BOOL APIENTRY DllMain( HMODULE hModule,
                       DWORD  ul_reason_for_call,
                       LPVOID lpReserved
                     )
{
    switch (ul_reason_for_call)
    {
    case DLL_PROCESS_ATTACH:
    case DLL_THREAD_ATTACH:
    case DLL_THREAD_DETACH:
    case DLL_PROCESS_DETACH:
        break;
    }
    return TRUE;
}

